### Nue

A deep learning framework sculpted for seamless implementation of models, geared towards entry level learners.

_Currently in Development, I'll be adding as I learn how to build_

### **Phase 1**

- [X]  Linear Regression Model
    - [x]  Implement
    - [X]  Write DocStrings
- [X]  Logistic Regression Model
    - [X]  Implement
    - [X]  Write DocStrings
- [X]  Vanilla Neural Networks
    - [X]  Implement
    - [X]  Write DocStrings

**Organize**

- [ ]  Optimize performance of each model
    - [ ]  Tune the operations and architecture (code)
- [ ]  Implement scaling / standardization functions
- [ ]  Ship ‘pip install neo_dl’ functionality once a stable version is released.
- [ ]  Implement a utility function that allows for easy split of test/train of csv data.
- [ ]  Functionality for loading params from a pkl file.
- [ ]  Functionality for saving params from a pkl file
- [ ]  Functionality for securely storing params other than a pkl file
- [ ]  Functionality for saving params securely other than a pkl file
- [ ]  Implement Loading Bar whilst the model is training
- [ ]  Implement __init__.py functionality under /neo_dl for ease of import for users.